package com.yunzhi.marketing.redpack.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.redpack.entity.TaRedPacketPerson;
import com.yunzhi.marketing.redpack.service.ITaRedPacketPersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 红包助力报名表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-06-03
 */
@RestController
@RequestMapping("/api")
public class TaRedPacketPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRedPacketPersonController.class);

    @Autowired
    public ITaRedPacketPersonService iTaRedPacketPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/redPacket/person/list",method= RequestMethod.GET)
    public ResponseBean taRedPacketPersonList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaRedPacketPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaRedPacketPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaRedPacketPerson> result = iTaRedPacketPersonService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRedPacketPersonList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taRedPacketPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taRedPacketPerson",method= RequestMethod.POST)
    public ResponseBean taRedPacketPersonAdd(@RequestBody TaRedPacketPerson taRedPacketPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRedPacketPersonService.save(taRedPacketPerson)){
                responseBean.addSuccess(taRedPacketPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRedPacketPersonAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taRedPacketPerson/{id}", method= RequestMethod.DELETE)
    public ResponseBean taRedPacketPersonDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaRedPacketPersonService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRedPacketPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRedPacketPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taRedPacketPerson/{id}",method= RequestMethod.PUT)
    public ResponseBean taRedPacketPersonUpdate(@PathVariable Integer id,
                                        @RequestBody TaRedPacketPerson taRedPacketPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRedPacketPersonService.updateById(taRedPacketPerson)){
                responseBean.addSuccess(taRedPacketPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRedPacketPersonUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taRedPacketPerson/{id}",method= RequestMethod.GET)
    public ResponseBean taRedPacketPersonGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaRedPacketPersonService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRedPacketPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
